@@ -1,20 +1,12 @@
 from json import loads
 import os
 
-print(os.path.join(os.path.dirname(__file__), "nk3.json"))
-
-
 def nori(args):
     verb = None
-    print(args)
     if args["Nori"] == "niri":
         if args["Modua"] == "Indikatiboa":
-            print("HERE")
             if args["Denbora"] == "Oraina":
-                print("HERE 2")
-                print(args["Aditza"])
                 verb = args["Aditza"].replace("(nori)", "t")
-                print(verb)
             if args["Denbora"] == "Iragana":
                 verb = args["Aditza"].replace("(nori)", "da")    
         if args["Modua"] == "Subjuntiboa":
@@ -26,16 +18,11 @@ def nori(args):
                 verb = args["Aditza"].replace("(nori)", "t")
         print("HALF IMPLEMENTED")
     if args["Nori"] == "hiri":
-        print("NOT IMPLEMENTED")
+        raise NotImplementedError("NOT IMPLEMENTED")
     if args["Nori"] == "hari":
-        print(args["Aditza"])
-        print(args["Modua"] == "Agintera" or args["Modua"] == "Ahalera")
-        print("i(nori)" in args["Aditza"])
         if (args["Modua"] == "Agintera" or args["Modua"] == "Ahalera") and not "i(nori)" in args["Aditza"]:
-            print("IO")
             verb = args["Aditza"].replace("(nori)", "io")
         else:
-            print("O")
             verb = args["Aditza"].replace("(nori)", "o")
     if args["Nori"] == "guri":
         verb = args["Aditza"].replace("(nori)", "gu")
@@ -44,7 +31,6 @@ def nori(args):
     if args["Nori"] == "zuei":
         verb = args["Aditza"].replace("(nori)", "zue")
     if args["Nori"] == "haiei":
-        print(args["Aditza"].endswith("i(nori)"))
         if (args["Modua"] == "Subjuntiboa" and args["Kasua"] == "NOR-NORI-NORK") or (args["Modua"] == "Agintera") and not "i(nori)" in args["Aditza"]:
             verb = args["Aditza"].replace("(nori)", "ie")
         else:
@@ -53,26 +39,20 @@ def nori(args):
 
 def nork(args):
     verb = None
-    print(args)
     if args["Nork"] == "nik":
         verb = args["Aditza"].replace("(nork)", "t")
     """if args["Nork"] == "hik":
     """
     if args["Nork"] == "hark":
         verb = args["Aditza"].replace("(nork)", "")
-        print("(NOTHING)")
     if args["Nork"] == "guk":
         verb = args["Aditza"].replace("(nork)", "gu")
-        print("gu")
     if args["Nork"] == "zuk":
         verb = args["Aditza"].replace("(nork)", "zu")
-        print("zu")
     if args["Nork"] == "zuek":
         verb = args["Aditza"].replace("(nork)", "zue")
-        print("zue")
     if args["Nork"] == "haiek":
         verb = args["Aditza"].replace("(nork)", "te")
-        print("e")
     return verb
 
 
@@ -86,13 +66,13 @@ def build(args):
     if args["Kasua"] == "NOR":
         if args["Nork"] != None or args["Nori"] != None:
             raise ValueError('Incorrect value for Nork and/or Nori: If Kasua = Nor, Nork and Nori must be = None. Read README.txt or the documentation at https://github.com/HCook86/Aditzak/blob/heroku/README.md for more information')
-        handler = open("nor.json", "r")
+        handler = open(os.path.join(os.path.dirname(__file__), "nor.json"), "r")
         file = loads(handler.read())
         try:
             args["Aditza"] = file[args["Modua"]][args["Denbora"]][args["Nor"]]
         except:
             args["Aditza"] = None
-            print("ERROR. NO EXISTE")
+            
 
     #If the case is NOR-NORI  
     elif args["Kasua"] == "NOR-NORI":
@@ -168,7 +148,6 @@ def build(args):
                 args["Aditza"] = args["Aditza"] + "te"
             
         if args["Modua"] == "Ondorioa":
-            print("ONDORIOA")
             if args["Nor"] == "ni":
                 args["Aditza"] = "nintzai"
             if args["Nor"] == "hi":
@@ -200,7 +179,6 @@ def build(args):
 
 
         if args["Modua"] == "Ahalera":
-            print("AHALERA")
             if args["Denbora"] == "Oraina":
                 if args["Nor"] == "ni":
                     args["Aditza"] = "naki"
@@ -265,9 +243,7 @@ def build(args):
 
 
         if args["Modua"] == "Subjuntiboa":
-            print("SUBJUNTIVO")
             if args["Denbora"] == "Oraina":
-                print("ORAINA")
                 if args["Nor"] == "ni":
                     args["Aditza"] = "naki"
                 if args["Nor"] == "hi":
@@ -287,7 +263,6 @@ def build(args):
                 
 
             if args["Denbora"] == "Iragana":
-                print("IRAGANA")
                 if args["Nor"] == "ni":
                     args["Aditza"] = "nenki"
                 if args["Nor"] == "hi":
@@ -312,7 +287,6 @@ def build(args):
 
 
         if args["Modua"] == "Agintera":
-            print("AGINTERA")
             if args["Nor"] == "hi":
                 args["Aditza"] = "haki"
             if args["Nor"] == "hura":
@@ -334,8 +308,7 @@ def build(args):
             
 
     elif args["Kasua"] == "NOR-NORK":
-        print("NOR-NORK")
-        handler = open("nk3.json", "r")
+        handler = open(os.path.join(os.path.dirname(__file__), "nk3.json"), "r")
         file = loads(handler.read())
         try:
             if args["Nor"] == "hura":
@@ -424,7 +397,6 @@ def build(args):
             if args["Denbora"] == "Iragana":
                 raise ValueError("Incorrect value for Denbora: Denbora only takes Oraina when Kasua is Agintera. Read README.txt or the documentation at https://github.com/HCook86/Aditzak/blob/heroku/README.md for more information")
             else:
-                print("NOR-NORK AGINTERA")
                 if args["Nor"] == "ni":
                     args["Aditza"] = "naza"
                 if args["Nor"] == "hura":
@@ -436,7 +408,6 @@ def build(args):
 
 
     elif args["Kasua"] == "NOR-NORI-NORK":
-        print("NOR-NORI-NORK")
         if args["Nor"] != "singularra" and args["Nor"] != "plurala":
             raise ValueError("Incorrect value for Nor: Nor only takes singularra or plurala when Kasua is NOR-NORI-NORK. Read README.txt or the documentation at https://github.com/HCook86/Aditzak/blob/heroku/README.md for more information")
         if args["Modua"] == "Baldintza":
@@ -475,7 +446,6 @@ def build(args):
         if args["Modua"] == "Subjuntiboa" or args["Modua"] == "Ahalera":
             
             args["Aditza"] = args["Aditza"] + "eza"
-            print(args["Aditza"])
             
             if args["Nor"] == "plurala":
                 args["Aditza"] = args["Aditza"] + "zki"
@@ -485,7 +455,6 @@ def build(args):
         args["Aditza"] = args["Aditza"] + "(nori)"
 
         args["Aditza"] = nori(args)
-        print("AFTER NORI " + args["Aditza"])
 
         if args["Modua"] == "Ahalera":
             args["Aditza"] = args["Aditza"] + "ke"
